@@ -12,7 +12,6 @@ from abc import ABCMeta, abstractmethod
 import numpy as np
 from collections import Counter
 from joblib import Parallel
-from inspect import signature
 
 import numpy as np
 from sklearn.base import ClassifierMixin, clone
@@ -318,7 +317,7 @@ class ImbalancedEnsembleClassifierMixin(ClassifierMixin):
         if (i_iter+1) == self.n_estimators:
             print(self._training_log_add_line(tabs=("┣", "╋", "┫", "━")))
             print(self._training_log_add_line(texts=(
-                    "final", f"{dict(Counter(y_resampled))}", 
+                    "final", f"{sort_dict_by_key(Counter(y_resampled))}", 
                     tuple(self._evaluate(data_name) for data_name in eval_data_names)
                 )))
             print(self._training_log_add_line(tabs=("┗", "┻", "┛", "━")))
@@ -412,7 +411,7 @@ class BaseImbalancedEnsemble(ImbalancedEnsembleClassifierMixin,
         """Validate the label vector."""
         y = column_or_1d(y, warn=True)
         check_classification_targets(y)
-        self.classes_, y = np.unique(y, return_inverse=True)
+        self.classes_, y_encoded = np.unique(y, return_inverse=True)
         self.n_classes_ = len(self.classes_)
         return y
 
@@ -484,6 +483,7 @@ class BaseImbalancedEnsemble(ImbalancedEnsembleClassifierMixin,
         self.features_ = np.arange(self.n_features_)
         self._n_samples = n_samples
         y = self._validate_y(y)
+        self._encode_map = {c: np.where(self.classes_==c)[0][0] for c in self.classes_}
 
         # Check parameters
         self._validate_estimator(default=DecisionTreeClassifier())
