@@ -196,6 +196,7 @@ class KmeansSMOTEBoostClassifier(ResampleBoostClassifier):
         self._sampler_class = _sampler_class
         self._properties = _properties
 
+        self.k_neighbors = k_neighbors
         self.k_neighbors_ = check_type(k_neighbors, 'k_neighbors', numbers.Integral)
         self.n_jobs_sampler = n_jobs_sampler
         self.kmeans_estimator = kmeans_estimator
@@ -342,7 +343,7 @@ if __name__ == '__main__':
 
 
     # %%
-    from visualizer import ImbalancedEnsembleVisualizer
+    from imbalanced_ensemble.visualizer import ImbalancedEnsembleVisualizer
 
     visualizer = ImbalancedEnsembleVisualizer(
         eval_datasets = None,
