@@ -220,6 +220,8 @@ class SMOTEBaggingClassifier(ResampleBaggingClassifier):
         self._sampling_type = _sampling_type
         self._sampler_class = _sampler_class
         self._properties = _properties
+        
+        self.k_neighbors = k_neighbors
         self.k_neighbors_ = check_type(k_neighbors, 'k_neighbors', numbers.Integral)
 
     
@@ -339,7 +341,7 @@ if __name__ == "__main__":
     
 
     # %%
-    from visualizer import ImbalancedEnsembleVisualizer
+    from imbalanced_ensemble.visualizer import ImbalancedEnsembleVisualizer
 
     visualizer = ImbalancedEnsembleVisualizer(
         eval_datasets = None,
