@@ -142,10 +142,6 @@ class SelfPacedEnsembleClassifier(BaseImbalancedEnsemble):
 
     RUSBoostClassifier : Random under-sampling integrated in AdaBoost.
 
-    Notes
-    -----
-    See :ref:`sphx_glr_auto_examples_basic_plot_basic_example.py` for an example.
-
     References
     ----------
     .. [1] Liu, Z., Cao, W., Gao, Z., Bian, J., Chen, H., Chang, Y., & Liu, T. Y. 
@@ -320,6 +316,7 @@ class SelfPacedEnsembleClassifier(BaseImbalancedEnsemble):
                     y_pred_proba=self.y_pred_proba_latest,
                     alpha=alpha,
                     classes_=classes_,
+                    encode_map=self._encode_map,
                     sample_weight=sample_weight)
 
             # Train a new base estimator on resampled data 
@@ -435,7 +432,7 @@ if __name__ == '__main__':
 
 
     # %%
-    from visualizer import ImbalancedEnsembleVisualizer
+    from imbalanced_ensemble.visualizer import ImbalancedEnsembleVisualizer
 
     visualizer = ImbalancedEnsembleVisualizer(
         eval_datasets = None,
